/***************************************************************************
                          vidVCD.h  -  description
                             -------------------
    begin                : Wed Aug 21 2002
    copyright            : (C) 2002 by mean
    email                : fixounet@free.fr

	

 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef vidVCD_H
#define vidVCD_H

uint8_t setSVCD( void );
uint8_t setVCD( void );
uint8_t setPSP(void);
uint8_t setPSPFullRes(void);
uint8_t setDVD( void );
uint8_t setHalfD1( void );
uint8_t setIPOD( void);

#endif
